**** graphmodelirf.do
*** Produces graphs from model simulations
*** Graphs the irfs from the model
*** Arezki,Ramey,Sheng July 2016

*** Requires:
***     ARS_model_simulations.xlsx

********************************************************************************
********************************************************************************
/* Part I: comparsion of IRF from models

All involve news that arrives at year 0 and is realized at year 4.
In all cases, the TFP and the reserves enter the production function as (-1)

Note that year = -1 gives the steady-state values before the news arrives */


*#delimit

graph drop _all

drop _all
clear all

set more 1

capture log close

  
  *****************************************************************************
  * Import Data from all experiments
  *****************************************************************************
  
  * Normalize so PV of oil increase GHH baseline is 1% of GDP in baseline
  *   These values were calculated in excel file
  * All of the exogenous TFP experiments were based on the baseline model endogenous reserve 
  *    process.  The one-sector experiments were scaled down within the dynare program

  scalar norm = 2 
  
  foreach experiment in oilghh oilkpr tfp2ghhsame tfp2ghhdiff { /* 2-sector models */
 
    import excel ARS_model_simulations.xlsx, sheet(`experiment') first
  
    keep year y n c svy iy r cay y1 y2 n1 n2 i1 i2 k1 k2 
    
    foreach var in y n c svy iy r cay y1 y2 n1 n2 i1 i2 k1 k2 {
       scalar `var'_ss = `var'  /* create steady-state scalar from year=-1 observation */
    }
  
    foreach var in y y1 y2 n n1 n2 i1 i2 c k1 k2  {
       gen `var'_`experiment' = 100*(ln(`var') - ln(`var'_ss))/norm
     }
  
    foreach var in svy iy r cay { /* compute percent difference from steady-state for rate vars */
       gen `var'_`experiment' = 100*(`var' - `var'_ss)/norm
    }
  
  
  summ y_`experiment' c_`experiment' if year<=50
  
   sort year
   save modelirf_`experiment'.dta, replace

   clear 
 
 }
 
 foreach experiment in tfp1ghh tfp1kpr { /* 1-sector models */
 
    import excel ARS_model_simulations.xlsx, sheet(`experiment') first
  
    keep year y n c svy iy r cay 
    
    foreach var in y n c svy iy r cay  {
       scalar `var'_ss = `var'  /* create steady-state scalar from year=-1 observation */
    }
  
    foreach var in y  n  c   {
       gen `var'_`experiment' = 100*(ln(`var') - ln(`var'_ss))/norm
     }
  
    foreach var in svy iy r cay { /* compute percent difference from steady-state for rate vars */
       gen `var'_`experiment' = 100*(`var' - `var'_ss)/norm
    }
  
  
  summ y_`experiment' c_`experiment' if year<=50
  
   sort year
   save modelirf_`experiment'.dta, replace

   clear 
 
 }

****  COMMENT AND UNCOMMENT SECTIONS BELOW TO PRODUCE EACH GRAPH


********************************************************************************
* Figure II: Baseline GHH and KPR
********************************************************************************
 use modelirf_oilghh.dta
 
 local other oilkpr
  
  
  merge 1:1 year using modelirf_`other'.dta
  
  drop _merge
  sort year
  
  drop if year<0 | year>20

 *** Set labels for graphs 

local y_`other'_lab `" "GDP" "'
local cay_`other'_lab `" "Current Account/GDP" "'
local svy_`other'_lab `" "Saving/GDP" "'
local iy_`other'_lab `" "Investment/GDP" "'
local c_`other'_lab `" "Consumption" "'
local n_`other'_lab `" "Hours" "'

foreach var in y cay svy iy c n {
   tw scatter `var'_oilghh `var'_`other' year, nodraw c(l l) clp(l -) clc(blue green) mc(blue green) clw(medthick medthick) ms(i i) yscale(range(0)) yline(0, lc(black) lw(thin)) scale(1.3) legend(off) title(``var'_`other'_lab', size(medium)) saving(`var'_`other'.gph, replace) 
 }
 

foreach var in c {
 tw scatter `var'_oilghh `var'_`other' year, nodraw c(l l) clp(l -) clc(blue green) mc(blue green) clw(medthick medthick) ms(i i) ylabel(0 0.05 0.1 0.15 0.2, grid) yline(0, lc(black) lw(thin)) scale(1.3) legend(off) title(``var'_`other'_lab', size(medium)) saving(`var'_`other'.gph, replace) 
 }
 
 foreach var in n {
 tw scatter `var'_oilghh `var'_`other' year, nodraw c(l l) clp(l -) clc(blue green) mc(blue green) clw(medthick medthick) ms(i i) ylabel(-0.05 0 0.05 0.1, grid) yline(0, lc(black) lw(thin)) scale(1.3) legend(off) title(``var'_`other'_lab', size(medium)) saving(`var'_`other'.gph, replace) 
 }

 
graph combine cay_`other'.gph y_`other'.gph  svy_`other'.gph  c_`other'.gph    iy_`other'.gph  n_`other'.gph, col(2) ysize(5) xsize(4) iscale(0.6) saving(`other'.gph, replace) name(`other',replace)
 
*powerpoint 
*graph combine cay_`other'.gph svy_`other'.gph  iy_`other'.gph  y_`other'.gph    c_`other'.gph  n_`other'.gph, col(3) ysize(4) xsize(7) iscale(0.8) saving(`other'.gph, replace) name(`other',replace)



/*
********************************************************************************
* Figure III: Baseline GHH vs. Same Shares TFP
********************************************************************************

use modelirf_oilghh.dta
 
  local other tfp2ghhsame
 
  
  merge 1:1 year using modelirf_`other'.dta
  
  drop _merge
  sort year
  
  *merge 1:1 year using modelirf_`other2'.dta
  
  drop if year<0 | year>20
  


 *** Set labels for graphs 

local y_`other'_lab `" "GDP" "'
local cay_`other'_lab `" "Current Account/GDP" "'
local svy_`other'_lab `" "Saving/GDP" "'
local iy_`other'_lab `" "Investment/GDP" "'
local c_`other'_lab `" "Consumption" "'
local n_`other'_lab `" "Hours" "'

foreach var in y cay svy iy c n {
   tw scatter `var'_oilghh `var'_`other' year, nodraw c(l l) clp(l -) clc(blue red) mc(blue red) clw(medthick medthick) ms(i i) yscale(range(0)) yline(0, lc(black) lw(thin)) scale(1.3) legend(off) title(``var'_`other'_lab', size(medium)) saving(`var'_`other'.gph, replace) 
 }

 
graph combine cay_`other'.gph y_`other'.gph  svy_`other'.gph  c_`other'.gph    iy_`other'.gph  n_`other'.gph, col(2) ysize(5) xsize(4) iscale(0.6) saving(`other'.gph, replace) name(`other',replace)
 
*powerpoint 
*graph combine cay_`other'.gph svy_`other'.gph  iy_`other'.gph  y_`other'.gph    c_`other'.gph  n_`other'.gph, col(3) ysize(4) xsize(7) iscale(0.8) saving(`other'.gph, replace) name(`other',replace)
*/

/*

*****************************
* C.I. SUPPLEMENTAL APPENDIX - SECTOR SPECIFIC GRAPHS FOR SUPPLEMENTAL APPENDIX
*****************************
use modelirf_oilghh.dta
 
local other oilkpr
   
  merge 1:1 year using modelirf_`other'.dta
  
  drop _merge
  sort year
  
  drop if year<0 | year>20

  
local y1_`other'_lab `" "Sector 1 Output" "'
local y2_`other'_lab `" "Sector 2 Output" "'

local n1_`other'_lab `" "Sector 1 Hours" "'
local n2_`other'_lab `" "Sector 2 Hours" "'

local i1_`other'_lab `" "Sector 1 Investment" "'
local i2_`other'_lab `" "Sector 2 Investment" "'

foreach var in y1 y2 n1 n2 i1 i2 {
   tw scatter `var'_oilghh `var'_`other' year, nodraw c(l l) clp(l -) clc(blue green) mc(blue green) clw(medthick medthick) ms(i i) yscale(range(0)) yline(0, lc(black) lw(thin)) scale(1.3) legend(off) title(``var'_`other'_lab', size(medium)) saving(`var'_`other'.gph, replace) 
 }
 
 
graph combine y1_`other'.gph y2_`other'.gph  n1_`other'.gph  n2_`other'.gph    i1_`other'.gph  i2_`other'.gph, col(2) ysize(5) xsize(4) iscale(0.6) saving(`other'.gph, replace) name(sector,replace)

*graph combine y1_`other'.gph n1_`other'.gph  i1_`other'.gph  y2_`other'.gph    n2_`other'.gph  i2_`other'.gph, col(3) ysize(4) xsize(7) iscale(0.7) saving(`other'.gph, replace) name(`other',replace)

*/


/*
*****************************
* C.II. SUPPLEMENTAL APPENDIX - AGGREGATE TFP SHOCK
*****************************

use modelirf_tfp1ghh.dta
 
  local other tfp1kpr  
  
  merge 1:1 year using modelirf_`other'.dta
  
  drop if year<0 | year>20
  
   *** Set labels for graphs 

local y_`other'_lab `" "GDP" "'
local cay_`other'_lab `" "Current Account/GDP" "'
local svy_`other'_lab `" "Saving/GDP" "'
local iy_`other'_lab `" "Investment/GDP" "'
local c_`other'_lab `" "Consumption" "'
local n_`other'_lab `" "Hours" "'


foreach var in y cay svy iy c n {
   tw scatter `var'_tfp1ghh `var'_`other' year, nodraw c(l l) clp(l -) clc(emidblue emerald) mc(emidblue emerald) clw(medthick medthick) ms(i i) yscale(range(0)) yline(0, lc(black) lw(thin)) scale(1.3) legend(off) title(``var'_`other'_lab', size(medium)) saving(`var'_`other'.gph, replace) 
 }
 
 
graph combine cay_`other'.gph y_`other'.gph  svy_`other'.gph  c_`other'.gph    iy_`other'.gph  n_`other'.gph, col(2) ysize(5) xsize(4) iscale(0.6) saving(`other'.gph, replace) name(`other',replace)
 
*powerpoint 
*graph combine cay_`other'.gph svy_`other'.gph  iy_`other'.gph  y_`other'.gph    c_`other'.gph  n_`other'.gph, col(3) ysize(4) xsize(7) iscale(0.8) saving(`other'.gph, replace) name(`other',replace)
*/

/*
*****************************
* EXTRA COMPARISON NOT SHOWN: 2-SECTOR EXOG TFP, COMPARE SAME SHARES TO DIFFERENT SHARE
*****************************

use modelirf_oilghh.dta
 
  local other tfp2ghhdiff
  local other2 tfp2ghhsame
  
  merge 1:1 year using modelirf_`other'.dta
  drop _merge
  sort year
  
  merge 1:1 year using modelirf_`other2'.dta
  drop _merge
  sort year
  
  drop if year<0 | year>20
  
   *** Set labels for graphs 

local y_`other'_lab `" "GDP" "'
local cay_`other'_lab `" "Current Account/GDP" "'
local svy_`other'_lab `" "Saving/GDP" "'
local iy_`other'_lab `" "Investment/GDP" "'
local c_`other'_lab `" "Consumption" "'
local n_`other'_lab `" "Hours" "'


foreach var in y cay svy iy c n {
   tw scatter `var'_oilghh `var'_`other' `var'_`other2' year, nodraw c(l l l) clp(l _ -) clc(blue purple red) mc(blue purple red) clw(medthick medthick) ms(i d i) yscale(range(0)) yline(0, lc(black) lw(thin)) scale(1.3) legend(off) title(``var'_`other'_lab', size(medium)) saving(`var'_`other'.gph, replace) 
 }
 
 
graph combine cay_`other'.gph y_`other'.gph  svy_`other'.gph  c_`other'.gph    iy_`other'.gph  n_`other'.gph, col(2) ysize(5) xsize(4) iscale(0.6) saving(`other'.gph, replace) name(`other',replace)
 
*powerpoint 
*graph combine cay_`other'.gph svy_`other'.gph  iy_`other'.gph  y_`other'.gph    c_`other'.gph  n_`other'.gph, col(3) ysize(4) xsize(7) iscale(0.8) saving(`other'.gph, replace) name(`other',replace)
*/
